Documentation
¶
Index ¶
- func EmptyTemplate() string
- func IsNoUpdatesError(err error) bool
- func ResolveFunc(raw any, params map[string]string) (string, error)
- type CFClient
- func (cf *CFClient) CancelStackUpdate(ctx context.Context, reqToken string, ...) error
- func (cf *CFClient) CreateChangeSet(ctx context.Context, reqToken string, msg *awsinfra_tpb.CreateChangeSetMessage) error
- func (cf *CFClient) CreateNewStack(ctx context.Context, reqToken string, msg *awsinfra_tpb.CreateNewStackMessage) error
- func (cf *CFClient) DeleteStack(ctx context.Context, reqToken string, stackName string) error
- func (cf *CFClient) GetChangeSet(ctx context.Context, stackName, changeSetName string) (*ChangeSetStatus, error)
- func (cf *CFClient) GetOneStack(ctx context.Context, stackName string) (*StackStatus, error)
- func (cf *CFClient) ImportResources(ctx context.Context, templateBody string, params []types.Parameter) (*ImportOutput, error)
- func (cf *CFClient) Logs(ctx context.Context, stackName string) ([]LogEvent, error)
- func (cf *CFClient) ScaleStack(ctx context.Context, reqToken string, msg *awsinfra_tpb.ScaleStackMessage) error
- func (cf *CFClient) UpdateStack(ctx context.Context, reqToken string, msg *awsinfra_tpb.UpdateStackMessage) error
- type ChangeSetStatus
- type DeferredParameterResolver
- type FuncJoin
- type ImportOutput
- type InfraWorker
- func (cf *InfraWorker) CancelStackUpdate(ctx context.Context, msg *awsinfra_tpb.CancelStackUpdateMessage) (*emptypb.Empty, error)
- func (cf *InfraWorker) CreateChangeSet(ctx context.Context, msg *awsinfra_tpb.CreateChangeSetMessage) (*emptypb.Empty, error)
- func (cf *InfraWorker) CreateNewStack(ctx context.Context, msg *awsinfra_tpb.CreateNewStackMessage) (*emptypb.Empty, error)
- func (cf *InfraWorker) HandleStackStatusChangeEvent(ctx context.Context, eventID string, event *StackStatusChangeEvent) error
- func (cf *InfraWorker) ScaleStack(ctx context.Context, msg *awsinfra_tpb.ScaleStackMessage) (*emptypb.Empty, error)
- func (cf *InfraWorker) StabalizeStack(ctx context.Context, msg *awsinfra_tpb.StabalizeStackMessage) (*emptypb.Empty, error)
- func (cf *InfraWorker) UpdateStack(ctx context.Context, msg *awsinfra_tpb.UpdateStackMessage) (*emptypb.Empty, error)
- type LogEvent
- type Resource
- type StackArgs
- type StackStatus
- type StackStatusChangeEvent
- type StackStatusChangeEvent_StatusDetails
- type Template
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmptyTemplate ¶
func EmptyTemplate() string
func IsNoUpdatesError ¶
Types ¶
type CFClient ¶
type CFClient struct {
// contains filtered or unexported fields
}
func NewCFAdapter ¶
func NewCFAdapter(clients *awsapi.DeployerClients) *CFClient
func (*CFClient) CancelStackUpdate ¶
func (cf *CFClient) CancelStackUpdate(ctx context.Context, reqToken string, msg *awsinfra_tpb.CancelStackUpdateMessage) error
func (*CFClient) CreateChangeSet ¶
func (cf *CFClient) CreateChangeSet(ctx context.Context, reqToken string, msg *awsinfra_tpb.CreateChangeSetMessage) error
func (*CFClient) CreateNewStack ¶
func (cf *CFClient) CreateNewStack(ctx context.Context, reqToken string, msg *awsinfra_tpb.CreateNewStackMessage) error
func (*CFClient) DeleteStack ¶
func (*CFClient) GetChangeSet ¶
func (*CFClient) GetOneStack ¶
func (*CFClient) ImportResources ¶
func (*CFClient) ScaleStack ¶
func (cf *CFClient) ScaleStack(ctx context.Context, reqToken string, msg *awsinfra_tpb.ScaleStackMessage) error
func (*CFClient) UpdateStack ¶
func (cf *CFClient) UpdateStack(ctx context.Context, reqToken string, msg *awsinfra_tpb.UpdateStackMessage) error
type ChangeSetStatus ¶
type ChangeSetStatus struct {
Status string
Lifecycle awsdeployer_pb.CFChangesetLifecycle
}
type DeferredParameterResolver ¶
type DeferredParameterResolver struct {
// contains filtered or unexported fields
}
func (*DeferredParameterResolver) Resolve ¶
func (dpr *DeferredParameterResolver) Resolve(ctx context.Context, input *awsdeployer_pb.CloudFormationStackParameterType, previous *types.Parameter) (string, error)
type ImportOutput ¶
type ImportOutput struct {
Imports []types.ResourceToImport
NewTemplate string
}
type InfraWorker ¶
type InfraWorker struct {
awsinfra_tpb.UnimplementedCloudFormationRequestTopicServer
*CFClient
// contains filtered or unexported fields
}
func NewInfraWorker ¶
func NewInfraWorker(db tokenstore.DBLite, adapter *CFClient) *InfraWorker
func (*InfraWorker) CancelStackUpdate ¶
func (cf *InfraWorker) CancelStackUpdate(ctx context.Context, msg *awsinfra_tpb.CancelStackUpdateMessage) (*emptypb.Empty, error)
func (*InfraWorker) CreateChangeSet ¶
func (cf *InfraWorker) CreateChangeSet(ctx context.Context, msg *awsinfra_tpb.CreateChangeSetMessage) (*emptypb.Empty, error)
func (*InfraWorker) CreateNewStack ¶
func (cf *InfraWorker) CreateNewStack(ctx context.Context, msg *awsinfra_tpb.CreateNewStackMessage) (*emptypb.Empty, error)
func (*InfraWorker) HandleStackStatusChangeEvent ¶
func (cf *InfraWorker) HandleStackStatusChangeEvent(ctx context.Context, eventID string, event *StackStatusChangeEvent) error
func (*InfraWorker) ScaleStack ¶
func (cf *InfraWorker) ScaleStack(ctx context.Context, msg *awsinfra_tpb.ScaleStackMessage) (*emptypb.Empty, error)
func (*InfraWorker) StabalizeStack ¶
func (cf *InfraWorker) StabalizeStack(ctx context.Context, msg *awsinfra_tpb.StabalizeStackMessage) (*emptypb.Empty, error)
StabalizeStack is sent to check that the stack is ready for a new deployment. It will emit a 'fake' status change event if the stack is in a stable state, so that the deployer can catch up with remote status.
func (*InfraWorker) UpdateStack ¶
func (cf *InfraWorker) UpdateStack(ctx context.Context, msg *awsinfra_tpb.UpdateStackMessage) (*emptypb.Empty, error)
type StackArgs ¶
type StackArgs struct {
Template *awsdeployer_pb.DeploymentState
Parameters []types.Parameter
}
type StackStatus ¶
type StackStatus struct {
StackStatus types.StackStatus
SummaryType awsdeployer_pb.CFLifecycle
IsOK bool
Stable bool
Parameters []*awsdeployer_pb.KeyValue
Outputs []*awsdeployer_pb.KeyValue
}
type StackStatusChangeEvent ¶
type StackStatusChangeEvent struct {
StackID string `json:"stack-id"`
ClientRequestToken string `json:"client-request-token"`
StatusDetails StackStatusChangeEvent_StatusDetails `json:"status-details"`
}
Click to show internal directories.
Click to hide internal directories.